==> aa_intercom-0.0.2-py2.py3-none-any.whl: aa_intercom/utils.py <==
# -*- coding: utf-8 -*-

from datetime import datetime
from django.conf import settings
from django.contrib.auth import get_user_model
from django.utils.timezone import make_aware, now
from intercom import errors
from intercom.client import Client

import pytz

intercom = Client(personal_access_token=settings.INTERCOM_API_ACCESS_TOKEN)


def upload_intercom_user(obj_id):
    """Creates or updates single user account on intercom
        Should be fine tuned per project.
    """
    UserModel = get_user_model()
    intercom_user = False
    instance = UserModel.objects.get(pk=obj_id)
    data = {
        "user_id": instance.intercom_id,
        "email": instance.email,
        "name": instance.get_full_name(),
        "last_request_at": instance.last_login.strftime("%s") if instance.last_login else "",
        "created_at": instance.date_joined.strftime("%s"),
    }

    data["custom_attributes"] = {
        "is admin": instance.is_superuser,
        # TODO: fine tune per project.
    }

    if not getattr(settings, "SKIP_INTERCOM", False):
        try:
            intercom_user = intercom.users.create(**data)
        except errors.ServiceUnavailableError:
            pass

    if intercom_user:
        UserModel.objects.filter(pk=obj_id).update(
            intercom_last_api_response=intercom_user.to_dict(),
            intercom_api_response_timestamp=make_aware(datetime.now(), pytz.UTC)
        )


def upload_not_registered_user_data(data):
    """
        Upload user data to intercom, actually any data passed
        data: Dict
        Required:
        "email"
    """
    if type(data) != dict:
        raise NotImplementedError("Incorrect data type")

    if not data.get("email"):
        raise KeyError("user_id as user.intercom_id or email is required")

    if not getattr(settings, "SKIP_INTERCOM", False):
        intercom_data = {
            "email": data.get("email"),
            "name": data.get("name"),
            "last_request_at": now().strftime("%s"),
        }
        del(data["email"])
        if data.get("name"):
            del(data["name"])
        if data:
            intercom_data["custom_attributes"] = data
        try:
            intercom.users.create(**intercom_data)
        except errors.ServiceUnavailableError:
            pass

==> aa_intercom-1.0.0-py2.py3-none-any.whl: aa_intercom/utils.py <==
# -*- coding: utf-8 -*-
from datetime import datetime

import pytz
from django.apps import apps
from django.conf import settings
from django.contrib.auth import get_user_model
from django.core.exceptions import ImproperlyConfigured
from django.utils.timezone import make_aware, now
from django.utils.translation import ugettext_lazy as _
from intercom import errors
from intercom.client import Client

intercom = Client(personal_access_token=settings.INTERCOM_API_ACCESS_TOKEN)


def get_intercom_event_model():
    try:
        app_label, model_name = getattr(settings, "INTERCOM_EVENT_MODEL", "").split(".", 1)
    except AttributeError:
        raise ImproperlyConfigured(_("INTERCOM_EVENT_MODEL must be provided in settings"))

    return apps.get_model(app_label, model_name)


def upload_intercom_user(obj_id):
    """Creates or updates single user account on intercom"""
    UserModel = get_user_model()
    intercom_user = False
    instance = UserModel.objects.get(pk=obj_id)
    data = instance.get_intercom_data()

    if not getattr(settings, "SKIP_INTERCOM", False):
        try:
            intercom_user = intercom.users.create(**data)
        except errors.ServiceUnavailableError:
            pass

    if intercom_user:
        UserModel.objects.filter(pk=obj_id).update(
            intercom_last_api_response=intercom_user.to_dict(),
            intercom_api_response_timestamp=make_aware(datetime.now(), pytz.UTC)
        )


def upload_not_registered_user_data(data):
    """
        Upload user data to intercom, actually any data passed
        data: Dict
        Required:
        "email"
    """
    if type(data) != dict:
        raise NotImplementedError("Incorrect data type")

    if not data.get("email"):
        raise KeyError("user_id as user.intercom_id or email is required")

    if not getattr(settings, "SKIP_INTERCOM", False):
        intercom_data = {
            "email": data.get("email"),
            "name": data.get("name"),
            "last_request_at": now().strftime("%s"),
        }
        del(data["email"])
        if data.get("name"):
            del(data["name"])
        if data:
            intercom_data["custom_attributes"] = data
        try:
            intercom.users.create(**intercom_data)
        except errors.ServiceUnavailableError:
            pass
